<?php

class Product_Comments extends Module {
	
	function __construct() {
		$this->name = 'product_comments';
		$this->tab = 'Products';
		$this->version = 1.0;

		parent::__construct();

		$this->page = basename(__FILE__, '.php');
		$this->displayName = '<font color="black">[EW]</font> ' . $this->l('Product\'s comments');
		$this->description = $this->l('Visitor can write and show comments on product page');
	}

	public function install() {
		if (!parent::install())
			return false;

		if (!$this->registerHook('productfooter'))
			return false;

		if (!Configuration::updateValue('EWPC_EVALUATION_ENABLE', 0))
			return false;
			
		if (!Configuration::updateValue('EWPC_ANONYMOUS_ENABLE', 0))
			return false;

		if (!Configuration::updateValue('EWPC_LANG_ALL', 1))
			return false;

		$query = 'CREATE TABLE '._DB_PREFIX_.'product_comments (
				`id_comment` int(2) NOT NULL AUTO_INCREMENT,
				`id_customer` INT(2) NOT NULL,
				`name_customer` VARCHAR(255) NOT NULL,
				`id_product` INT(2) NOT NULL,
				`id_lang` INT(2) NOT NULL,
				`date` VARCHAR(255) NOT NULL,
				`evaluation` INT(2) NOT NULL,
				`comment` TEXT NOT NULL,
				PRIMARY KEY(`id_comment`)
			) ENGINE=MyISAM default CHARSET=utf8';
	 	if (!Db::getInstance()->Execute($query))
	 		return false;

		return true;
	}
	
    public function uninstall() {
	 	if (!parent::uninstall())
	 		return false;
	 	
	 	if (!Db::getInstance()->Execute('DROP TABLE '._DB_PREFIX_.'product_comments'))
	 		return false;
	 	
	 	if (!Configuration::deleteByName('EWPC_EVALUATION_ENABLE'))
	 		return false;

	 	if (!Configuration::deleteByName('EWPC_ANONYMOUS_ENABLE'))
	 		return false;
	 	
	 	if (!Configuration::deleteByName('EWPC_LANG_ALL'))
	 		return false;
	 	
	 	return true;
    }

	public function getContent() {
		$output = '<h2>'.$this->displayName.'</h2>';
		if (Tools::isSubmit('submitEWPC'))
		{
			$anonymous = Tools::getValue('anonymous');
			$lang = Tools::getValue('lang');
			
			Configuration::updateValue('EWPC_ANONYMOUS_ENABLE', ($anonymous == 'on' ? 1 : 0));
			Configuration::updateValue('EWPC_LANG_ALL', ($lang == 'on' ? 1 : 0));
		}
		return $output.$this->displayForm();
	}

	public function displayForm() {
		$output = '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			<fieldset><legend>'.$this->l('Settings').'</legend>
				<label>'.$this->l('Anonymous').'</label>
				<div class="margin-form">
					<input type="checkbox" name="anonymous" '.(Configuration::get('EWPC_ANONYMOUS_ENABLE') ? 'checked' : '').' />
					<p class="clear">'.$this->l('Accept or not anonymous post ? (not registered users)').'</p>
				</div>
				
				<label>'.$this->l('Language').'</label>
				<div class="margin-form">
					<input type="checkbox" name="lang" '.(Configuration::get('EWPC_LANG_ALL') ? 'checked' : '').' />
					<p class="clear">'.$this->l('Show all posts of any languages ?').'</p>
				</div>
				
				<center><input type="submit" name="submitEWPC" value="'.$this->l('Save').'" class="button" /></center>
			</fieldset>
		</form>';
		return $output;
	}

	public function hookProductFooter($params) {
		global $smarty, $cookie;
		
		if (isset($_POST['EWPC_form_submit']))
			$this->processPOST($params);
		
		$smarty->assign('EWPC_EVALUATION_ENABLE', Configuration::get('EWPC_EVALUATION_ENABLE'));
		$smarty->assign('EWPC_ANONYMOUS_ENABLE', Configuration::get('EWPC_ANONYMOUS_ENABLE'));
		$smarty->assign('EWPC_LANG_ALL', Configuration::get('EWPC_LANG_ALL'));

		$comments = $this->getComments($_GET['id_product'], false, (Configuration::get('EWPC_ANONYMOUS_ENABLE') ? true : false), (Configuration::get('EWPC_LANG_ALL') ? 'all' : $params['cookie']->id_lang));
		$smarty->assign('comments', $comments);
		$smarty->assign('nb_comments', count($comments));
				
		if (!$params['cart']->id_customer)
			$smarty->assign('user_isconnected', 0);
		else
			$smarty->assign('user_isconnected', 1);
		
		return $this->display(__FILE__, 'product_comments.tpl');
	}
	
	public function getComments($id_product, $evaluation = false, $anonymous = false, $lang = 'all') {
	 	global $cookie;
	 	$result = array();
	 	$out = array();
	 	
	 	$query = 'SELECT * FROM '._DB_PREFIX_.'product_comments WHERE `id_product` = '.intval($id_product);
	 	if (!$anonymous)
	 		$query .= ' AND `id_customer` != 0';
	 	if ($lang != 'all')
	 		$query .= ' AND `id_lang` = '.intval($lang);
	 	$query .= ' ORDER BY `date`';
	 	
	 	if (!$out = Db::getInstance()->ExecuteS($query))
	 		return array();
	 	
	 	$i = 0;
	 	foreach ($out AS $comment) {
		 	$result[$i]['name_customer'] = $comment['name_customer'];
			$result[$i]['id_lang'] = $comment['id_lang'];
			$result[$i]['date'] = Tools::displayDate(date("Y-m-d H:i:s", $comment['date']), $cookie->__get('id_lang'));
			$result[$i]['evaluation'] = $comment['evaluation'];
			$result[$i]['comment'] = $comment['comment'];
			$i++;
		}		
	 	return $result;
	}
	
	public function processPOST($params) {
		if (!Configuration::get('EWPC_ANONYMOUS_ENABLE') && !$params['cart']->id_customer)
			return false;
		elseif (!Configuration::get('EWPC_ANONYMOUS_ENABLE') && isset($_POST['EWPC_form_anonymous']))
			return false;

		$id_customer = $params['cart']->id_customer;
		if (!$id_customer)
			$name_customer = $this->l('Anonymous');
		elseif ($_POST['EWPC_form_anonymous'] == 'on')
			$name_customer = $this->l('Anonymous');
		else
			$name_customer = $params['cookie']->customer_firstname.' '.strtoupper(substr($params['cookie']->customer_lastname, 0, 1)).'.';
		$id_product = $_GET['id_product'];
		$id_lang = $params['cookie']->id_lang;
		$evaluation = (isset($_POST['EWPC_form_evaluation']) ? intval($_POST['EWPC_form_evaluation']) : 0);
		$comment = $_POST['EWPC_form_comment'];
		
		$this->addComment($id_customer, $name_customer, $id_product, $id_lang, $evaluation, $comment);
	}
	
	public function addComment($id_customer, $name_customer, $id_product, $id_lang, $evaluation, $comment) {
		$query = 'INSERT INTO '._DB_PREFIX_.'product_comments VALUES (\'\', '.intval($id_customer).', \''.pSQL($name_customer).'\', '.intval($id_product).', '.intval($id_lang).',\''.time().'\' ,'.intval($evaluation).', \''.pSQL($comment).'\')';
	 	if (!Db::getInstance()->Execute($query) OR !$lastId = mysql_insert_id())
	 		return false;
	 	return true;
	}
	
}

?>